# CraftBeerPi4 plugin for Gembird USB Socket 

With this plugin you can use a [Gembird USB socket](https://gembird.com/item.aspx?id=7415&lang=en) as actor.


## Installation

Before you can install this plugin, you will need to install a an additional package manually. 

`sudo apt-get sispmctl`

Once these packages have been isntalled, you need to install and activate the plugin on your system. 

You can either install it directly from pypi.org via:

`sudo pip3 install cbpi4-GembirdUSB`

or from the GITHub repo via:

`sudo pip3 install https://github.com/avollkopf/cbpi4-GembirdUSB/archive/main.zip`


## Usage

- Add an Actor under Hardware and Chosse GembirdUSB
- Select port 1-4 for your actor
- Up to 4 actors can be added 

### Changelog

29.01.22: (0.0.1) Initial Commit

